@@ -6,7 +6,7 @@ DDNS
 @modified: rufengsuixing
 """
 from __future__ import print_function
-from time import ctime
+from time import ctime, asctime
 from os import path, environ, name as os_name
 from tempfile import gettempdir
 from logging import DEBUG, basicConfig, info, warning, error, debug
@@ -18,7 +18,7 @@ from util import ip
 from util.cache import Cache
 from util.config import init_config, get_config
 
-__version__ = "v2.11.5@2022-07-28T14:50:06+00:00"  # CI 时会被Tag替换
+__version__ = "v2.12.0@2022-12-07T12:11:57+00:00"  # CI 时会被Tag替换
 __description__ = "automatically update DNS records to dynamic local IP [自动更新DNS记录指向本地IP]"
 __doc__ = """
 ddns[%s]
@@ -27,15 +27,13 @@ ddns[%s]
 Copyright (c) New Future (MIT License)
 """ % (__version__)
 
-environ["DDNS_VERSION"] = "v2.11.5"
+environ["DDNS_VERSION"] = "v2.12.0"
 
 if getattr(sys, 'frozen', False):
     # https://github.com/pyinstaller/pyinstaller/wiki/Recipe-OpenSSL-Certificate
     environ['SSL_CERT_FILE'] = path.join(
         getattr(sys, '_MEIPASS'), 'lib', 'cert.pem')
 
-CACHE_FILE = path.join(gettempdir(), 'ddns.cache')
-
 
 def get_ip(ip_type, index="default"):
     """
@@ -75,8 +73,8 @@ def change_dns_record(dns, proxy_list, **kw):
         else:
             dns.PROXY = proxy
         record_type, domain = kw['record_type'], kw['domain']
-        print('\n%s(%s) ==> %s [via %s]' %
-              (domain, record_type, kw['ip'], proxy))
+        print('\n%s %s(%s) ==> %s [via %s]' %
+              (asctime(), domain, record_type, kw['ip'], proxy))
         try:
             return dns.update_record(domain, kw['ip'], record_type=record_type)
         except Exception as e:
@@ -139,7 +137,9 @@ def main():
     proxy_list = proxy if isinstance(
         proxy, list) else proxy.strip('; ').replace(',', ';').split(';')
 
-    cache = get_config('cache', True) and Cache(CACHE_FILE)
+    cache = get_config('cache', True)
+    cache = cache is True and path.join(gettempdir(), 'ddns.cache') or cache
+    cache = Cache(cache)
     if cache is False:
         info("Cache is disabled!")
     elif get_config("config_modified_time") is None or get_config("config_modified_time") >= cache.time:
